.. _api_formapi_section:

:mod:`repoze.formapi.form`
-----------------------------

.. automodule:: repoze.formapi.form

  .. autoclass:: Form
     :members:

  .. autoclass:: Proxy
     :members:

  .. method:: action
  
  .. method:: validator
  
